@@ -141,6 +141,10 @@ END
 
    TRACKS   => 'Tracks',
 
+   TRACK_SELECT   => 'Search for Specific Tracks',
+
+   TRACK_NAME     => 'Track name',
+
    EXTERNAL_TRACKS => '<i>External tracks italicized</i>',
 
    OVERVIEW_TRACKS => '<sup>*</sup>Overview track',
@@ -165,6 +169,8 @@ END
 
    CONFIGURE_TRACKS   => 'Configure tracks...',
 
+   SELECT_SUBTRACKS   => 'Click to select subtracks...',
+
    EDIT       => 'Edit File...',
 
    DELETE     => 'Delete File',
@@ -193,6 +199,8 @@ END
 
    CLEAR_HIGHLIGHTING => 'Clear highlighting',
 
+   CLEAR       => 'Clear',
+
    UPDATE      => 'Update',
 
    UPDATE_TRACKS => 'Update Tracks',
@@ -219,7 +227,9 @@ END
 
    REMOTE_TITLE => 'Add remote annotations',
 
-   REMOTE_URL   => 'Enter Remote Annotation URL',
+   REMOTE_URL   => 'Enter remote track URL',
+
+   REMOTE_URL_HELP => 'Enter the URL of a remote DAS track, GBrowse track, or internet-accessible track definition file.',
 
    UPDATE_URLS  => 'Update',
 
@@ -362,8 +372,6 @@ END
 
    NO_EXTERNAL        => 'No external features loaded.',
 
-   NO_CITATION        => 'No additional information available.',
-
    #--------------
    # PLUGIN PAGES
    #--------------
@@ -440,7 +448,15 @@ END
 
  SHOW_OR_HIDE_TRACK => '<b>Show or hide this track</b>',
 
- CONFIGURE_THIS_TRACK   => '<b>Click to change track settings.</b>',
+ KILL_THIS_TRACK    => '<b>Turn off this track.</b>',
+
+ CONFIGURE_THIS_TRACK   => '<b class="error">Configure this track.</b>',
+
+ SUBTRACKS_SHOWN    => 'This track contains selectable subtracks:',
+
+ SHOW_SUBTRACKS     => '<b>Select subtracks</b>',
+
+ SHOWING_SUBTRACKS  => '(<i>Showing %d of %d subtracks</i>)',
 
  SHARE_THIS_TRACK   => '<b>Share this track</b>',
 
@@ -451,7 +467,7 @@ END
  SHARE_INSTRUCTIONS_ONE_TRACK => <<END,
 To share this track with another GBrowse genome browser,
 first copy the URL below, then go to the other GBrowse and
-paste the URL into the "Enter Remote Annotation" field at
+paste the URL into the "Enter remote track URL" field at
 the bottom of the page. If this track is from an uploaded file,
 then be aware that sharing this URL with another user potentially
 allows <b>all</b> your uploaded data to be viewable by that user.
@@ -460,7 +476,7 @@ END
  SHARE_INSTRUCTIONS_ALL_TRACKS => <<END,
 To share all currently selected tracks with another GBrowse genome
 browser, first copy the URL below, then go to the other GBrowse and
-paste the URL into the "Enter Remote Annotation" field at
+paste the URL into the "Enter remote track URL" field at
 the bottom of the page. If any of the selected tracks are from an uploaded file,
 then be aware that sharing this URL with another user potentially
 allows <b>all</b> your uploaded data to be viewable by that user.
